  /* 
   * Get a color from the color map image based on plot value from bathymetry
   */
  function convertLonToLeft(longitude) {
	left = (longitude - -71.91320801)/(-70.97058105 - -71.91320801) * 1732;
	return Math.floor(left);
  }
  
  function convertLatToTop(latitude) {
	tp = (latitude - 41.13315883)/(42.0129787 - 41.13315883) * 2141;
	return Math.floor((2141-tp)*.75);
  }
  
  /* 
   * draw buoy information on top of the bathymetry basemap
   */
  var buoys = [
  ['id','water_temp','longitude','latitude'],
  ['FOXR1',5.4,-71.401,41.807],
  ['CPTR1',5.5,-71.345,41.717],
  ['PTCR1',999,-71.34,41.638],
  ['FRVM3',999,-71.164,41.704],
  ['BLTM3',5.3,-71.174,41.704],
  ['NAXR1',5.1,-71.339,41.637],
  ['QPTR1',4.9,-71.407,41.586],
  ['NWPR1',4.7,-71.326,41.504],
  ['BUZM3',5.0,-71.033,41.397],
  ['B2',5.2,-71.357,41.671],
  ['B4',5.4,-71.371,41.74],
  ['B6',4.8,-71.383,41.638],
  ['B7',4.9,-71.377,41.591],
  ['B10',5.2,-71.215,41.704],
  ['B12',5.2,-71.215,41.68],
  ['B13',5.0,-71.321,41.648],
  ['B14',5.6,-71.42,41.679],
  ['F3',4.9,-71.32,41.583],
  ['F4',5.4,-71.374,41.84],
  ['F5',5.5,-71.443,41.687],
  ['F7',4.8,-71.418,41.493]
  ]

  var canvas = document.getElementById("buoyCanvas");
  var context = canvas.getContext("2d");
  context.font = "30px Arial";

  for (i=1; i<buoys.length; i++) {
  	context.fillStyle = "rgba(255,0,0,.5)";
	context.beginPath();
	context.arc(convertLonToLeft(buoys[i][2]), convertLatToTop(buoys[i][3]), 8, 0, 2 * Math.PI);
	context.fill();
	context.fillStyle = "#ffffff";
	if(buoys[i][1] < 999) {
		context.fillText("" + buoys[i][1], convertLonToLeft(buoys[i][2])+2, convertLatToTop(buoys[i][3]));
	}
  }

  /* 
   * Get a color from the color map image based on plot value from bathymetry
   */
  function getColor(value) {
    color = [];
    depth = document.getElementById('extent').value;
    
    if(value != undefined && value < 0) {
		value = value*-741/depth;
		//below is how to access to your pixel details (stored in four integers)
		red=imgData.data[Math.floor(value)*4];
		green=imgData.data[Math.floor(value)*4+1];
		blue=imgData.data[Math.floor(value)*4+2];
		alpha=imgData.data[Math.floor(value)*4+3];
		color = [red,green,blue];   	
    } else {
		color = [0,0,0];
  	}
  	
  	return color;
  }

  /* 
   * Plot the bathymetry by creating pixels for each row, column combination
   */
  function plot(data, ncols, row) {
    values = data.split(' ');
  	for(i=0; i<ncols; i++) {
	  var c = document.getElementById("plot");
	  var ctx = c.getContext("2d");
	  color = getColor(values[i]);
	  ctx.fillStyle = "rgba("+color[0]+","+color[1]+","+color[2]+",1)";
	  ctx.fillRect( i, row, 1, 1 );
	}
  }
  
  /* 
   * Read and plot the user's chosen .asc file
   */
  document.getElementById('file').onchange = function() {
	var file = this.files[0];
	var reader = new FileReader();
	reader.onload = function(progressEvent){
	  //Read the lines into an array
	  var lines = this.result.split('\n');
	  var ncols = lines[0].split(' ');
	  ncols = ncols[1];
	  var nrows = lines[1].split(' ');
	  nrows = nrows[1];
	  document.getElementById('plot').width = ncols;
	  document.getElementById('plot').height = nrows;
	  var count=0;
	  for(var line = 6; line < lines.length; line++){
		plot(lines[line], ncols, count);
		count++;
	  }
	};
	reader.readAsText(file);
	document.getElementById('gui').style.display = "none";
  };
